summaryrefslogtreecommitdiffstats
path: root/update_jdn.sh
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2016-05-29 18:53:59 +0200
committerHolger Levsen <holger@layer-acht.org>2016-05-29 18:53:59 +0200
commit7451e2071278ccc74d8459e637bcdfc0b54b2525 (patch)
tree7561ddc21ce121f77ed10c92746426c29a17a301 /update_jdn.sh
parent8fc2346fc3b7cb421985e44a8a71361b083a680d (diff)
downloadjenkins.debian.net-7451e2071278ccc74d8459e637bcdfc0b54b2525.tar.xz
only count phil once
Diffstat (limited to 'update_jdn.sh')
-rwxr-xr-xupdate_jdn.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/update_jdn.sh b/update_jdn.sh
index 58f63dd6..e48fdbdf 100755
--- a/update_jdn.sh
+++ b/update_jdn.sh
@@ -479,8 +479,8 @@ if [ "$HOSTNAME" = "jenkins" ] ; then
git log | grep ^Author| cut -d " " -f2-|sort -u -f > $TMPFILE
echo "----" >> $TMPFILE
sudo tee /var/lib/jenkins/userContent/THANKS > /dev/null < THANKS.head
- # samuel, lunar and josch committed with several commiters, only display one
- grep -v -e "samuel.thibault@ens-lyon.org" -e Lunar -e "j.schauer@email.de" -e "mattia@mapreri.org" $TMPFILE | sudo tee -a /var/lib/jenkins/userContent/THANKS > /dev/null
+ # samuel, lunar, josch and phil committed with several commiters, only display one
+ grep -v -e "samuel.thibault@ens-lyon.org" -e Lunar -e "j.schauer@email.de" -e "mattia@mapreri.org" -e "phil@jenkins-test-vm" $TMPFILE | sudo tee -a /var/lib/jenkins/userContent/THANKS > /dev/null
rm $TMPFILE
TMPDIR=$(mktemp -d -t update-jdn-XXXXXXXX)
sudo cp -pr userContent $TMPDIR/